@@ -34,7 +34,7 @@ pub type c_void = std::ffi::c_void;
 
 pub type Context = *const c_void;
 pub type CustomCommand = extern "C" fn(Context) -> HandlerResult;
-pub type CustomSerializer = extern "C" fn(*const c_char) -> *mut c_void;
+pub type CustomLoader = extern "C" fn(*const c_char) -> *mut c_void;
 
 #[cfg_attr(target_arch = "x86", link(name = "cleo_redux"))]
 #[cfg_attr(target_arch = "x86_64", link(name = "cleo_redux64"))]
@@ -116,11 +116,11 @@ extern "C" {
     ///
     /// since v2
     fn RuntimeNextTick(current_time: u32, time_step: i32);
-    /// Registers a new serializer for files with the extension
+    /// Registers a new loader for files with the extension
     ///
     /// since v3
-    fn RegisterSerializer(extension: *const c_char, cb: CustomSerializer);
-    /// Allocates a memory chunk with size in bytes
+    fn RegisterLoader(extension: *const c_char, cb: CustomLoader);
+    /// Allocates a memory chunk with size in bytes. Memory is guaranteed to be zero initialized
     ///
     /// since v3
     fn AllocMem(size: usize) -> *mut c_void;
@@ -292,17 +292,17 @@ pub fn to_rust_string(addr: *const i8) -> String {
     }
 }
 
-/// Registers a new serializer for files with the extension
+/// Registers a new loader for files with the extension
 ///
 /// since v3
 #[allow(dead_code)]
-pub fn register_serializer(extension: &str, cb: CustomSerializer) {
+pub fn register_loader(extension: &str, cb: CustomLoader) {
     unsafe {
-        RegisterSerializer(sz!(extension), cb);
+        RegisterLoader(sz!(extension), cb);
     }
 }
 
-/// Allocates a memory chunk with size in bytes
+/// Allocates a memory chunk with size in bytes. Memory is guaranteed to be zero initialized
 ///
 /// since v3
 #[allow(dead_code)]
